"""
Implements the AXA Remote library for controlling AXA Remote window openers.

Created on 12 Nov 2022

@author: Rogier van Staveren
"""

__version__ = "0.0.6"

from axaremote.axaremote import (
    AXARemote,
    AXARemoteError,
    AXARemoteSerial,
    AXARemoteTelnet,
)
